#[non_exhaustive]pub enum ChainlinkEventDecodeError {
WrongTopic {
expected: B256,
actual: Option<B256>,
},
WrongTopicCount {
expected: usize,
actual: usize,
},
WrongDataLength {
expected: usize,
actual: usize,
},
Uint64Overflow {
field: &'static str,
value: U256,
},
AbiDecode {
event: &'static str,
message: String,
},
}Expand description
Errors returned by Chainlink event decoding.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
WrongTopic
The log did not contain the expected event signature topic.
WrongTopicCount
The log had the wrong number of topics.
WrongDataLength
The data payload had the wrong byte length.
Uint64Overflow
A uint256 event field did not fit into the crate’s typed Rust field.
AbiDecode
ABI decoding failed for a dynamic or typed event payload.