#[non_exhaustive]pub enum PendingOracleSourceError {
PendingUpdatesDisabled,
SourceDisabled {
transport: PendingOracleSource,
},
DuplicateSource {
id: PendingOracleSourceId,
},
RuntimeUnavailable,
Transport(String),
Task(String),
}Available on crate feature
pending-oracle-updates only.Expand description
Failure to start or run a pending source.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PendingUpdatesDisabled
Pending updates were not enabled on the runtime.
SourceDisabled
The source family was not enabled in super::PendingOracleConfig.
Fields

transport: PendingOracleSourceDisabled transport family.
DuplicateSource
A live source session already owns this stable source id.
Fields

id: PendingOracleSourceIdConflicting stable source identifier.
No Tokio runtime was available to own the source task.
Transport(String)
The source connection or protocol failed.
Task(String)
The source task panicked or was cancelled unexpectedly.