#[non_exhaustive]pub enum PendingOracleStatus {
Pending,
Landed,
Reverted,
}Available on crate feature
pending-oracle-updates only.Expand description
Report-level pending lifecycle state.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Pending
At least one transport variant may still land.
Landed
A variant landed and emitted its matching committed oracle signal.
Reverted
Every known variant resolved without the matching oracle update.