#[non_exhaustive]pub enum PendingOracleTransmissionStatus {
Pending,
Landed,
Reverted,
Dropped,
Superseded,
}Available on crate feature
pending-oracle-updates only.Expand description
Lifecycle state of one transaction variant.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Pending
The variant has been observed but not canonically resolved.
Landed
The transaction landed and emitted the matching oracle confirmation signal.
Reverted
The transaction landed but reverted or did not emit the expected signal.
Dropped
The source no longer exposes this variant and it was not observed landing.
Superseded
A newer variant replaced this transport attempt.