pub struct EulerOracleAdapter { /* private fields */ }Available on crate feature
euler only.Expand description
Cache-backed Euler price oracle discovery adapter.
Implementations
Sourceimpl EulerOracleAdapter
impl EulerOracleAdapter
Sourcepub fn router(router: Address) -> Self
pub fn router(router: Address) -> Self
Create an adapter that resolves quote pairs through EulerRouter.
Sourcepub fn oracle(oracle: Address, base: Address, quote: Address) -> Self
pub fn oracle(oracle: Address, base: Address, quote: Address) -> Self
Create an adapter for one direct oracle quote pair.
Sourcepub fn quote_pair(self, pair: EulerQuotePair) -> Self
pub fn quote_pair(self, pair: EulerQuotePair) -> Self
Add one quote pair.
Sourcepub fn quote_pairs(
self,
pairs: impl IntoIterator<Item = EulerQuotePair>,
) -> Self
pub fn quote_pairs( self, pairs: impl IntoIterator<Item = EulerQuotePair>, ) -> Self
Add multiple quote pairs.
Sourcepub fn now_timestamp(self, now_timestamp: u64) -> Self
pub fn now_timestamp(self, now_timestamp: u64) -> Self
Set a fixed timestamp for deterministic registration status classification.