pub struct MorphoBlueOracleAdapter { /* private fields */ }Available on crate feature
morpho only.Expand description
Cache-backed Morpho Blue oracle discovery adapter.
Implementations
Sourceimpl MorphoBlueOracleAdapter
impl MorphoBlueOracleAdapter
Sourcepub fn new(morpho: Address) -> Self
pub fn new(morpho: Address) -> Self
Create an adapter that can discover market params from a Morpho Blue contract.
Sourcepub fn from_oracle(oracle: Address) -> Self
pub fn from_oracle(oracle: Address) -> Self
Create an adapter for a direct Morpho oracle address.
Sourcepub fn market(self, market: MorphoBlueMarket) -> Self
pub fn market(self, market: MorphoBlueMarket) -> Self
Add one market registration.
Sourcepub fn markets(
self,
markets: impl IntoIterator<Item = MorphoBlueMarket>,
) -> Self
pub fn markets( self, markets: impl IntoIterator<Item = MorphoBlueMarket>, ) -> Self
Add multiple market registrations.
Sourcepub fn now_timestamp(self, now_timestamp: u64) -> Self
pub fn now_timestamp(self, now_timestamp: u64) -> Self
Set a fixed timestamp for deterministic registration status classification.