pub struct OracleCodeRegistry { /* private fields */ }Expand description
Registry of oracle bytecode claims to install before discovery or simulation.
Implementations
Sourceimpl OracleCodeRegistry
impl OracleCodeRegistry
Sourcepub fn seed(self, address: Address, code: Bytes) -> Self
pub fn seed(self, address: Address, code: Bytes) -> Self
Add a canonical runtime bytecode claim that must verify once.
Sourcepub fn seed_many<I>(self, seeds: I) -> Self
pub fn seed_many<I>(self, seeds: I) -> Self
Add multiple canonical runtime bytecode claims that must verify once.
Sourcepub fn etch(self, address: Address, code: Bytes) -> Self
pub fn etch(self, address: Address, code: Bytes) -> Self
Add an explicit simulation-only code etch.
Sourcepub fn etch_many<I>(self, etches: I) -> Self
pub fn etch_many<I>(self, etches: I) -> Self
Add multiple explicit simulation-only code etches.
Sourcepub fn with_seed(self, seed: OracleCodeSeed) -> Self
pub fn with_seed(self, seed: OracleCodeSeed) -> Self
Append an already-built seed.
Sourcepub fn seeds(&self) -> &[OracleCodeSeed]
pub fn seeds(&self) -> &[OracleCodeSeed]
Return registered seed entries.
Sourcepub fn apply_to_cache(&self, cache: &mut EvmCache) -> OracleCodeWarmupReport
pub fn apply_to_cache(&self, cache: &mut EvmCache) -> OracleCodeWarmupReport
Install code entries into the cache and verify canonical seeds.
Sourcepub fn apply_to_cache_with_policy(
&self,
cache: &mut EvmCache,
policy: OracleCodeWarmupPolicy,
) -> Result<OracleCodeWarmupReport, OracleError>
pub fn apply_to_cache_with_policy( &self, cache: &mut EvmCache, policy: OracleCodeWarmupPolicy, ) -> Result<OracleCodeWarmupReport, OracleError>
Install code entries, verify canonical seeds, and enforce policy.