pub struct OracleReactiveHandler { /* private fields */ }Expand description
Reactive-runtime bridge for Chainlink-compatible oracle feeds.
Implementations
Sourceimpl OracleReactiveHandler
impl OracleReactiveHandler
Sourcepub fn new(registrations: Vec<FeedRegistration>) -> Self
pub fn new(registrations: Vec<FeedRegistration>) -> Self
Create a handler from current feed registrations.
Sourcepub fn with_storage_sync(
registrations: Vec<FeedRegistration>,
storage_sync: OracleStorageSync,
) -> Self
pub fn with_storage_sync( registrations: Vec<FeedRegistration>, storage_sync: OracleStorageSync, ) -> Self
Create a handler from current feed registrations and storage adapters.
Sourcepub fn interests(&self) -> Vec<ReactiveInterest<Ethereum>>
pub fn interests(&self) -> Vec<ReactiveInterest<Ethereum>>
Interests for current aggregators.
Sourcepub fn handle_for_test(
&self,
ctx: &ReactiveContext,
input: &ReactiveInput<Ethereum>,
) -> Result<HandlerOutcome, HandlerError>
pub fn handle_for_test( &self, ctx: &ReactiveContext, input: &ReactiveInput<Ethereum>, ) -> Result<HandlerOutcome, HandlerError>
Test helper that avoids requiring callers to construct a cache view.