pub struct OracleSnapshot {
pub id: FeedId,
pub proxy: Address,
pub aggregator: Option<Address>,
pub metadata: FeedMetadata,
pub round: RoundData,
pub round_status: OracleRoundStatus,
pub value_status: OracleValueStatus,
pub source: OracleValueSource,
pub block_number: Option<u64>,
pub block_hash: Option<B256>,
/* private fields */
}Expand description
Typed current oracle state for one registered proxy feed.
Fields
id: FeedIdRegistered feed id.
proxy: AddressUser-facing proxy address.
aggregator: Option<Address>Best-known current aggregator address.
metadata: FeedMetadataFeed metadata read from the proxy.
round: RoundDataCurrent round data.
round_status: OracleRoundStatusCurrent round validity status.
value_status: OracleValueStatusCurrent value reconciliation lifecycle.
source: OracleValueSourceState source.
block_number: Option<u64>Block number associated with the observation, when known.
block_hash: Option<B256>Block hash associated with the observation, when known.
Implementations
Sourceimpl OracleSnapshot
impl OracleSnapshot
Sourcepub fn requires_reconciliation(&self) -> bool
pub fn requires_reconciliation(&self) -> bool
Return true when callers should repair this snapshot via proxy read.