pub struct PendingOracleResolution {
pub update_id: PendingOracleUpdateId,
pub transmission_id: PendingOracleTransmissionId,
pub transaction_hash: B256,
pub block_number: u64,
pub kind: PendingOracleResolutionKind,
}Available on crate feature
pending-oracle-updates only.Expand description
Correlation between one pending transport variant and its committed outcome.
Fields
update_id: PendingOracleUpdateIdStable report identity.
transmission_id: PendingOracleTransmissionIdStable transport variant identity.
transaction_hash: B256Hash of the committed transaction.
block_number: u64Block containing the resolved attempt.
kind: PendingOracleResolutionKindOracle-confirmed outcome.
Implementations
Sourceimpl PendingOracleResolution
impl PendingOracleResolution
Sourcepub const fn new(
update_id: PendingOracleUpdateId,
transmission_id: PendingOracleTransmissionId,
transaction_hash: B256,
block_number: u64,
kind: PendingOracleResolutionKind,
) -> Self
pub const fn new( update_id: PendingOracleUpdateId, transmission_id: PendingOracleTransmissionId, transaction_hash: B256, block_number: u64, kind: PendingOracleResolutionKind, ) -> Self
Construct a committed resolution after matching its oracle signal.